@@ -51,7 +51,7 @@ class JsonParseNode(ParseNode, Generic[T, U]):
         Returns:
             Optional[ParseNode]: A new parse node for the given identifier
         """
-        if self._json_node and identifier:
+        if self._json_node and self._json_node.get(identifier):
             return JsonParseNode(self._json_node[identifier])
         return None
 
@@ -281,10 +281,9 @@ class JsonParseNode(ParseNode, Generic[T, U]):
             return
 
         for key, val in object_dict.items():
-            snake_case_key = re.sub(r'(?<!^)(?=[A-Z])', '_', key).lower()
-            deserializer = fields.get(snake_case_key)
+            deserializer = fields.get(key)
             if deserializer:
                 deserializer(JsonParseNode(val))
             else:
                 # if item_additional_data:
-                item_additional_data[snake_case_key] = val
+                item_additional_data[key] = val
